<?php
return [
    'cache' => [
        'frontend' => [
            'default' => [
                'backend' => 'Magento\\Framework\\Cache\\Backend\\Redis',
                'backend_options' => [
                    'server' => '127.0.0.1',
                    'port' => '6379',
                    'load_from_slave' => [
                        'server' => '127.0.0.1',
                        'port' => '6379'
                    ],
                    'read_timeout' => 1,
                    'retry_reads_on_master' => 1,
                    'database' => 1
                ],
                'frontend_options' => [
                    'write_control' => false
                ]
            ],
            'page_cache' => [
                'backend' => 'Magento\\Framework\\Cache\\Backend\\Redis',
                'backend_options' => [
                    'server' => '127.0.0.1',
                    'port' => '6379',
                    'load_from_slave' => [
                        'server' => '127.0.0.1',
                        'port' => '26379'
                    ],
                    'read_timeout' => 1,
                    'retry_reads_on_master' => 1,
                    'database' => 2
                ],
                'frontend_options' => [
                    'write_control' => false
                ]
            ]
        ]
    ],
    'MAGE_MODE' => 'developer',
    'cache_types' => [
        'compiled_config' => 1,
        'config' => 1,
        'layout' => 1,
        'block_html' => 1,
        'collections' => 1,
        'reflection' => 1,
        'db_ddl' => 1,
        'eav' => 1,
        'customer_notification' => 1,
        'config_integration' => 1,
        'config_integration_api' => 1,
        'full_page' => 1,
        'target_rule' => 1,
        'config_webservice' => 1,
        'translate' => 1,
        'vertex' => 1
    ],
    'cron' => [

    ],
    'backend' => [
        'frontName' => 'admin'
    ],
    'queue' => [
        'amqp' => [
            'host' => '127.0.0.1',
            'port' => 5672,
            'user' => 'guest',
            'password' => 'guest',
            'virtualhost' => '/'
        ],
        'consumers_wait_for_messages' => 0
    ],
    'db' => [
        'connection' => [
            'default' => [
                'host' => '127.0.0.1',
                'username' => 'root',
                'dbname' => '{{site}}',
                'password' => 'root'
            ]
        ]
    ],
    'crypt' => [
        'key' => '{{crypt_key}}'
    ],
    'resource' => [
        'default_setup' => [
            'connection' => 'default'
        ]
    ],
    'x-frame-options' => 'SAMEORIGIN',
    'session' => [
        'save' => 'redis',
        'redis' => [
            'host' => '127.0.0.1',
            'port' => '6379',
            'database' => 0,
            'disable_locking' => 1
        ]
    ],
    'directories' => [
        'document_root_is_pub' => true
    ],
    'downloadable_domains' => [
        '{{site}}.test'
    ],
    'install' => [
        'date' => 'Mon, 12 Abr 2021 04:00:00 +0000'
    ],
    'cron_consumers_runner' => [
        'cron_run' => true,
        'max_messages' => 10000,
        'consumers' => [

        ]
    ],
    'system' => [
        'default' => [
            'catalog' => [
                'search' => [
                    'engine' => 'elasticsearch7',
                    'elasticsearch7_server_hostname' => '127.0.0.1',
                    'elasticsearch7_server_port' => '9200',
                    'elasticsearch7_index_prefix' => '{{site}}'
                ]
            ],
            'admin' => [
                'url' => [
                    'custom_path' => 'admin',
                    'use_custom' => '0'
                ]
            ]
        ]
    ]
];
